import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Animal.  This is the base class for all animals.  It provides the ability
 * to move, turn, and eat.
 * 
 * @author Michael Kolling
 * @author Mihaela Sabin
 * @author Brian Gailis
 * @author Teddy Rokas
 * @version 2011-10-12
 *    - changed Remove (line 84, col 17) to eat
 */
public class Animal extends Actor
{
    ////////////////// Class constants ////////////////////
    private static final double WALKING_SPEED = 5.0;
    
    ////////////////// Constuctors ///////////////////
    
    /////////////////// Methods /////////////////////  
    /**
     * Turns the given number of degrees to the right (that is, clockwise).
     * @param angle The number of degrees this animal turns to the right.
     */
    public void turn(int angle)
    {
        setRotation(getRotation() + angle);
    }
    

    /**
     * Moves forward in the current direction as determined from current rotation.
     */
    public void move()
    {
        double angle = Math.toRadians( getRotation() );
        int x = (int) Math.round(getX() + Math.cos(angle) * WALKING_SPEED);
        int y = (int) Math.round(getY() + Math.sin(angle) * WALKING_SPEED);
        
        setLocation(x, y);
    }

    
    /**
     * Tests if this animal is close to one of the edges of the world. 
     * @return True if at the edge, false otherwise.
     * Note that 20 pixels is the margin for "touching" an edge. 
     */
    public boolean atWorldEdge()
    {
        //If current x is too close to 0 or too close to world's width
        if(getX() < 20 || getX() > getWorld().getWidth() - 20) {
            return true; //return value is true and method execution stops here.
        }
        //If condition above was false 
        //AND current y is too close to 0 or too close to world's height
        if(getY() < 20 || getY() > getWorld().getHeight() - 20) {
            return true; //return value is true and method execution stops here.
        }

        //None of the conditions above was true. 
        return false;//return value is false and method execution stops here.
    }
    
    
    /**
     * Tests if this animal overlaps with another object of given class.
     * @param clss The class of the object that might be at the location this animal is at.
     * @return True if this animal overlaps with another object of given class.
     * False if there is no such object at the same location.
     */
    public boolean canSee(Class clss)
    {
        Actor actor = getOneObjectAtOffset(0, 0, clss);
        return actor != null;        
    }
       
    
}
