import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Describes the Cat object.
 *  - moves randomly
 *  - eats cats and ends game with sound
 * @author Brian Gailis 
 * @author Teddy Rokas
 * @author Paskale Odongo 
 * @version 2011-11-23
 */


public class Cat extends Animal
{
private GreenfootImage image1;
private GreenfootImage image2;
private static double WALKING_SPEED = 0;



    /**
     * creates a cat and Intialize its 2 images.
     * 
     */
    
    public Cat()
    {
        
       image1= new GreenfootImage("imagesCat1.png");
       image2= new GreenfootImage("imagesCat2.png");
       setImage(image1);
        
        
    }
    
     /**
     * Alternate the cats's image between image1 and image2.
     */
    public void switchImage()
    {
        if (getImage() == image1) 
        {
            setImage(image2);
        }
        else
        {
            setImage(image1);
        }
    }
    
    
    /**
     * Act - do whatever the Cat wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act()
    {
        turnAtEdge();    
        randomTurn();
        move();
        lookForMouse();
        check();
        switchImage();
    }
    /**
     * Moves forward in the current direction as determined from current rotation.
     */
    public void move()
    {
        double angle = Math.toRadians( getRotation() );
        int x = (int) Math.round(getX() + Math.cos(angle) * WALKING_SPEED);
        int y = (int) Math.round(getY() + Math.sin(angle) * WALKING_SPEED);
        
        setLocation(x, y);
    }
    /**
     * Check whether we have stumbled upon a mouse.
     * If we have, eat it.  If not, do nothing
     */
    public void lookForMouse()
    {
        if ( canSee(Mouse.class) )
        {
            eat(Mouse.class);
            Greenfoot.playSound("slurp.wav");
            Greenfoot.playSound("fanfare.wav");
            Greenfoot.stop();
            MouseWorld world = (MouseWorld) getWorld();
            world.gameOver("YOU LOSE");
        }
    }
    
    /**
     * Eats an object of the given class if there is one at the location this animal is at.
     * @param - The class of the object that might be at the location this animal is at.
     */
    public void eat(Class clss)
    {
        Actor actor = getOneObjectAtOffset(0, 0, clss);
        if(actor != null) {
            getWorld().removeObject(actor);
        }
        
    }
  
    public void check()
    {
        if (Greenfoot.isKeyDown("up"))
            {
             WALKING_SPEED = 20.0;
            }else{
                if (Greenfoot.isKeyDown("down"))
                {
                WALKING_SPEED = 20.0;
                }else{
                    if (Greenfoot.isKeyDown("left"))
                    {
                    WALKING_SPEED = 20.0;
                    }else{
                        if (Greenfoot.isKeyDown("right"))
                        {
                        WALKING_SPEED = 20.0;
                        }else{WALKING_SPEED = 5.0;
                        }
                    }
                } 
            }
    }

    /**
     * When moving, turn randomly
     */
    public void randomTurn()
    {
        if ( Greenfoot.getRandomNumber(100) < 10 )
        {
            turn(Greenfoot.getRandomNumber(90)-45);
        }
    }
    /**
     * If at world edge turn
     */
    public void turnAtEdge()
    {
       if ( atWorldEdge() )
        {
            turn(Greenfoot.getRandomNumber(100));
        }
    }    
}
