import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Write a description of class Mouse here.
 * @author Michael Kolling
 * @author Mihaela Sabin
 *      - Mouse extends Animal to inherit 'canSee' and 'eat' methods and  
 *          to pass them to subclass Mouse in Mouse scenario.
 *      - added 'moveUp' and 'moveDown', which are coded after 'walk'

 * @author Brian Gailis
 * @author Teddy Rokas
 * @version 2011-10-12
 * @version 2011-10-31 BTG
 *       - Changed the Walk methods to check for numberOfCheese
 *       - Added an array to the mouse image 
 *           
 *           
 */
public class Mouse extends Animal
{
    /////////////////////// Instance variables ////////////////////////
    public int numberOfCheese;
    
    private String[] mouseImg = {
        "mouse-little-up-tail-right.png",   //0
        "mouse-little-up-tail-left.png",    //1
        "mouse-little-right-tail-up.png",   //2
        "mouse-little-right-tail-down.png", //3
        "mouse-little-left-tail-up.png",    //4
        "mouse-little-left-tail-down.png",  //5
        "mouse-little-down-tail-right.png", //6
        "mouse-little-down-tail-left.png",  //7
        "mouse-biggest-up-tail-right.png",  //8
        "mouse-biggest-up-tail-left.png",   //9
        "mouse-biggest-right-tail-up.png",  //10
        "mouse-biggest-right-tail-down.png", //11
        "mouse-biggest-left-tail-up.png",   //12
        "mouse-biggest-left-tail-down.png", //13
        "mouse-biggest-down-tail-right.png",//14 
        "mouse-biggest-down-tail-left.png"};//15
    
    
   //////////////////////// Constructors ////////////////////////////////
    /**
     * Creates a Mouse and initializes its image and sets its initial state.
     */
    public Mouse( ) 
    {
        setImage(mouseImg [0]);
        this.numberOfCheese = 0;
                
    }    

    ////////////////////////// Methods ///////////////////////////////
    
    
    /**
     * Act - do whatever the Mouse wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        keyControlMove( );
        lookForCheese( );
        
    }
     
    public void keyControlMove( )
    {
        
        if (Greenfoot.isKeyDown("up") )
        {
            walkUp(1);
        }
        if (Greenfoot.isKeyDown("down") )
        {
            walkDown(1);
        }
        if (Greenfoot.isKeyDown("left") )
        {
            walkLeft(1);
        }
        if (Greenfoot.isKeyDown("right") )
        {
            walkRight(1);
        }
    }
    
    public void lookForCheese( )
    {
        if (canSee(Cheese.class))
        {
            eat(Cheese.class); //make it disappear
            this.numberOfCheese = this.numberOfCheese + 1;//count this cheese
            Greenfoot.playSound("slurp.wav");
            if (this.numberOfCheese == 8)
            {
                Greenfoot.playSound("slurp.wav");
                Greenfoot.playSound("fanfare.wav");
                Greenfoot.stop();
                MouseWorld world = (MouseWorld) getWorld();
                world.gameOver("WINNER!!!!");
            }
        }
    }
    
    /**
     * The cat walks up 
     * @param Distance that the cat moves in the up direction.Small numbers (1 to 10) are recommended
     */
    public void walkUp(int distance)
    {
        if ( this.numberOfCheese <= 4)
        {
            walk(distance, 0, -10, mouseImg[0], mouseImg[1]);
        }
        else
        {
            walk(distance, 0, -10, mouseImg[8], mouseImg[9]);
        }
    }
    
    /**
     * The cat walks down  
     * @param Distaance that the cat walks in the down directin.Small numbers (1 to 10) are recommended
     */
    public void walkDown(int distance)
    {
        if ( this.numberOfCheese <= 4)
        {
            walk(distance,0, 10, mouseImg [6], mouseImg [7]);
        }
        else
        {
            walk(distance,0, 10, mouseImg [14], mouseImg [15]);
        }
    }
    
    
    /**
     * Walks a bit to the left. 
     * @param distance - determines how far to walk. Small numbers (1 to 10) are recommended.
     */
    public void walkLeft(int distance)
    {
        if ( this.numberOfCheese <= 4)
        {
            walk(distance, -10, 0, mouseImg [4], mouseImg [5]);
        }
        else
        {
            walk(distance, -10, 0, mouseImg [12], mouseImg [13]);
        }
    }
    
    /**
     * Walk a bit to the right. 
     * @param distance - determines how far to walk. Small numbers (1 to 10) are recommended.
     */
    public void walkRight(int distance)
    {
        if ( this.numberOfCheese <= 4)
        {
            walk(distance, 10, 0, mouseImg [2], mouseImg [3]);
        }
        else
        {
            walk(distance, 10, 0, mouseImg [10], mouseImg [11]);
        }
    }
    
   
    /**
     * Walks a given distance into a given direction, using given images.
     * @param distance - how far to walk
     * @param direction - in which direction to go
     * @param img1 - image displayed during walking, in alternation with img2
     * @param img2 - image displayed during walking, in alternation with img1
     */
    private void walk(int distance, int xDirection, int yDirection, String img1, String img2)
    {
        for (int i = 0; i < distance; i++) 
        {
            setImage(img1);
            wait(2);
            setLocation(getX( ) + xDirection, getY() + yDirection);
            setImage(img2);
            wait(2);
            setLocation(getX() + xDirection, getY() + yDirection);
        }
    }
    
    /**
     * Eats an object of the given class if there is one at the location this animal is at.
     * @param - The class of the object that might be at the location this animal is at.
     */
    public void eat(Class clss)
    {
        Actor actor = getOneObjectAtOffset(0, 0, clss);
        if(actor != null) {
            ateSomeCheese();
            getWorld().removeObject(actor);
        }
        
    }
    
    private void ateSomeCheese()
    {
        MouseWorld MouseWorld = (MouseWorld) getWorld();
        Counter counter = MouseWorld.getCounter();
        counter.bumpCount(1);
    }

    /**
     *  A delay in the game 
     *  @param time that the mouse waits 
     */
        
    public void wait(int time)
    {
        Greenfoot.delay(time);
    }
    
}
