import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;


/**
 * Creates the mouse world.  World size is 560x560 cells and is just 1 pixel
 * It auto populates the world when opened with One Mouse, 8 Cats, 8 pieces of Cheese
 * 
 * @author Brian Gailis
 * @author Teddy Rokas
 * @version 2011-10-12
 * @version 2011-10-31 BTG
 *          - Added display for cheese eaten
 *          - Added Array to load mouse images
 * @version 2011-11-23 BTG
 *          - Edited the populateWorld() method
 *              -Set the addObject new Mouse to static start position low right corner
 *              -Set the addObject new Cat to randomly place cats upper left corner
 */
public class MouseWorld extends World
{ 
    
    private Counter theCounter;
    
    /**
     * Constructor for objects of class MouseWorld.
     * Creates world size
     * Automatically populates world
     */
    public MouseWorld()
    {    
        super(560, 560, 1);
        populateWorld();
        theCounter = new Counter();
        addObject(theCounter, 58, 538);
    }
       
    public Counter getCounter()
    {
        return theCounter;
    }
    
    /**
     * Automatically populates mouseWorld
     * Five Cats Randomly in the upper left corner of world
     * One Mouse Static position in the low right corner of world
     * Eight pieces of Cheese Randomly in world
     */
    public void populateWorld()
    {
        //Adds Mouse upon game start to a static position in low right corner of world
        addObject( new Mouse(), 381, 461);
        
        for (int i = 0; i < 8; i++)
        {
            addObject( new Cheese(), Greenfoot.getRandomNumber(560), Greenfoot.getRandomNumber(560));
        }
        
        //Adds Cat upon game start to random position is upper left corner of world
        for (int i = 0; i < 5; i++)
        {
            int x = Greenfoot.getRandomNumber(getWidth()/2);
            int y = Greenfoot.getRandomNumber(getHeight()/2);
            addObject( new Cat(), x, y);
        }
    }
    
    /**
     * This method is called when the game is over to display the final score.
     * @param - String Displays a string message is displayed
     */
    public void gameOver(String message) 
    {
        addObject(new ScoreBoard(theCounter.totalCount, message), getWidth()/2, getHeight()/2);
    }    
    
    
}
